==> servicecatalog-model-6.3.0-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceBindingSpecFluent<A extends ServiceBindingSpecFluent<A>> extends Fluent<A>{
  public String getExternalID();
  public A withExternalID(String externalID);
  public Boolean hasExternalID();
  
  /**
   * This method has been deprecated, please use method buildInstanceRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getInstanceRef();
  public LocalObjectReference buildInstanceRef();
  public A withInstanceRef(LocalObjectReference instanceRef);
  public Boolean hasInstanceRef();
  public A withNewInstanceRef(String name);
  public ServiceBindingSpecFluent.InstanceRefNested<A> withNewInstanceRef();
  public ServiceBindingSpecFluent.InstanceRefNested<A> withNewInstanceRefLike(LocalObjectReference item);
  public ServiceBindingSpecFluent.InstanceRefNested<A> editInstanceRef();
  public ServiceBindingSpecFluent.InstanceRefNested<A> editOrNewInstanceRef();
  public ServiceBindingSpecFluent.InstanceRefNested<A> editOrNewInstanceRefLike(LocalObjectReference item);
  public A addToParameters(String key,Object value);
  public A addToParameters(Map<String,Object> map);
  public A removeFromParameters(String key);
  public A removeFromParameters(Map<String,Object> map);
  public Map<String,Object> getParameters();
  public <K,V>A withParameters(Map<String,Object> parameters);
  public Boolean hasParameters();
  public A addToParametersFrom(Integer index,ParametersFromSource item);
  public A setToParametersFrom(Integer index,ParametersFromSource item);
  public A addToParametersFrom(io.fabric8.servicecatalog.api.model.ParametersFromSource... items);
  public A addAllToParametersFrom(Collection<ParametersFromSource> items);
  public A removeFromParametersFrom(io.fabric8.servicecatalog.api.model.ParametersFromSource... items);
  public A removeAllFromParametersFrom(Collection<ParametersFromSource> items);
  public A removeMatchingFromParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParametersFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParametersFromSource> getParametersFrom();
  public List<ParametersFromSource> buildParametersFrom();
  public ParametersFromSource buildParametersFrom(Integer index);
  public ParametersFromSource buildFirstParametersFrom();
  public ParametersFromSource buildLastParametersFrom();
  public ParametersFromSource buildMatchingParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  public Boolean hasMatchingParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  public A withParametersFrom(List<ParametersFromSource> parametersFrom);
  public A withParametersFrom(io.fabric8.servicecatalog.api.model.ParametersFromSource... parametersFrom);
  public Boolean hasParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> addNewParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> addNewParametersFromLike(ParametersFromSource item);
  public ServiceBindingSpecFluent.ParametersFromNested<A> setNewParametersFromLike(Integer index,ParametersFromSource item);
  public ServiceBindingSpecFluent.ParametersFromNested<A> editParametersFrom(Integer index);
  public ServiceBindingSpecFluent.ParametersFromNested<A> editFirstParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> editLastParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> editMatchingParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  public String getSecretName();
  public A withSecretName(String secretName);
  public Boolean hasSecretName();
  public A addToSecretTransforms(Integer index,SecretTransform item);
  public A setToSecretTransforms(Integer index,SecretTransform item);
  public A addToSecretTransforms(io.fabric8.servicecatalog.api.model.SecretTransform... items);
  public A addAllToSecretTransforms(Collection<SecretTransform> items);
  public A removeFromSecretTransforms(io.fabric8.servicecatalog.api.model.SecretTransform... items);
  public A removeAllFromSecretTransforms(Collection<SecretTransform> items);
  public A removeMatchingFromSecretTransforms(Predicate<SecretTransformBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSecretTransforms instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SecretTransform> getSecretTransforms();
  public List<SecretTransform> buildSecretTransforms();
  public SecretTransform buildSecretTransform(Integer index);
  public SecretTransform buildFirstSecretTransform();
  public SecretTransform buildLastSecretTransform();
  public SecretTransform buildMatchingSecretTransform(Predicate<SecretTransformBuilder> predicate);
  public Boolean hasMatchingSecretTransform(Predicate<SecretTransformBuilder> predicate);
  public A withSecretTransforms(List<SecretTransform> secretTransforms);
  public A withSecretTransforms(io.fabric8.servicecatalog.api.model.SecretTransform... secretTransforms);
  public Boolean hasSecretTransforms();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> addNewSecretTransform();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> addNewSecretTransformLike(SecretTransform item);
  public ServiceBindingSpecFluent.SecretTransformsNested<A> setNewSecretTransformLike(Integer index,SecretTransform item);
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editSecretTransform(Integer index);
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editFirstSecretTransform();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editLastSecretTransform();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editMatchingSecretTransform(Predicate<SecretTransformBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo();
  public UserInfo buildUserInfo();
  public A withUserInfo(UserInfo userInfo);
  public Boolean hasUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> withNewUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item);
  public ServiceBindingSpecFluent.UserInfoNested<A> editUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> editOrNewUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item);
  public interface InstanceRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<ServiceBindingSpecFluent.InstanceRefNested<N>>{
    public N and();
    public N endInstanceRef();
    
  }
  public interface ParametersFromNested<N> extends Nested<N>,ParametersFromSourceFluent<ServiceBindingSpecFluent.ParametersFromNested<N>>{
    public N and();
    public N endParametersFrom();
    
  }
  public interface SecretTransformsNested<N> extends Nested<N>,SecretTransformFluent<ServiceBindingSpecFluent.SecretTransformsNested<N>>{
    public N and();
    public N endSecretTransform();
    
  }
  public interface UserInfoNested<N> extends Nested<N>,UserInfoFluent<ServiceBindingSpecFluent.UserInfoNested<N>>{
    public N and();
    public N endUserInfo();
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingSpecFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceBindingSpecFluent<A extends ServiceBindingSpecFluent<A>> extends Fluent<A>{
  public String getExternalID();
  public A withExternalID(String externalID);
  public Boolean hasExternalID();
  
  /**
   * This method has been deprecated, please use method buildInstanceRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getInstanceRef();
  public LocalObjectReference buildInstanceRef();
  public A withInstanceRef(LocalObjectReference instanceRef);
  public Boolean hasInstanceRef();
  public A withNewInstanceRef(String name);
  public ServiceBindingSpecFluent.InstanceRefNested<A> withNewInstanceRef();
  public ServiceBindingSpecFluent.InstanceRefNested<A> withNewInstanceRefLike(LocalObjectReference item);
  public ServiceBindingSpecFluent.InstanceRefNested<A> editInstanceRef();
  public ServiceBindingSpecFluent.InstanceRefNested<A> editOrNewInstanceRef();
  public ServiceBindingSpecFluent.InstanceRefNested<A> editOrNewInstanceRefLike(LocalObjectReference item);
  public A addToParameters(String key,Object value);
  public A addToParameters(Map<String,Object> map);
  public A removeFromParameters(String key);
  public A removeFromParameters(Map<String,Object> map);
  public Map<String,Object> getParameters();
  public <K,V>A withParameters(Map<String,Object> parameters);
  public Boolean hasParameters();
  public A addToParametersFrom(int index,ParametersFromSource item);
  public A setToParametersFrom(int index,ParametersFromSource item);
  public A addToParametersFrom(io.fabric8.servicecatalog.api.model.ParametersFromSource... items);
  public A addAllToParametersFrom(Collection<ParametersFromSource> items);
  public A removeFromParametersFrom(io.fabric8.servicecatalog.api.model.ParametersFromSource... items);
  public A removeAllFromParametersFrom(Collection<ParametersFromSource> items);
  public A removeMatchingFromParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParametersFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParametersFromSource> getParametersFrom();
  public List<ParametersFromSource> buildParametersFrom();
  public ParametersFromSource buildParametersFrom(int index);
  public ParametersFromSource buildFirstParametersFrom();
  public ParametersFromSource buildLastParametersFrom();
  public ParametersFromSource buildMatchingParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  public Boolean hasMatchingParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  public A withParametersFrom(List<ParametersFromSource> parametersFrom);
  public A withParametersFrom(io.fabric8.servicecatalog.api.model.ParametersFromSource... parametersFrom);
  public Boolean hasParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> addNewParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> addNewParametersFromLike(ParametersFromSource item);
  public ServiceBindingSpecFluent.ParametersFromNested<A> setNewParametersFromLike(int index,ParametersFromSource item);
  public ServiceBindingSpecFluent.ParametersFromNested<A> editParametersFrom(int index);
  public ServiceBindingSpecFluent.ParametersFromNested<A> editFirstParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> editLastParametersFrom();
  public ServiceBindingSpecFluent.ParametersFromNested<A> editMatchingParametersFrom(Predicate<ParametersFromSourceBuilder> predicate);
  public String getSecretName();
  public A withSecretName(String secretName);
  public Boolean hasSecretName();
  public A addToSecretTransforms(int index,SecretTransform item);
  public A setToSecretTransforms(int index,SecretTransform item);
  public A addToSecretTransforms(io.fabric8.servicecatalog.api.model.SecretTransform... items);
  public A addAllToSecretTransforms(Collection<SecretTransform> items);
  public A removeFromSecretTransforms(io.fabric8.servicecatalog.api.model.SecretTransform... items);
  public A removeAllFromSecretTransforms(Collection<SecretTransform> items);
  public A removeMatchingFromSecretTransforms(Predicate<SecretTransformBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSecretTransforms instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SecretTransform> getSecretTransforms();
  public List<SecretTransform> buildSecretTransforms();
  public SecretTransform buildSecretTransform(int index);
  public SecretTransform buildFirstSecretTransform();
  public SecretTransform buildLastSecretTransform();
  public SecretTransform buildMatchingSecretTransform(Predicate<SecretTransformBuilder> predicate);
  public Boolean hasMatchingSecretTransform(Predicate<SecretTransformBuilder> predicate);
  public A withSecretTransforms(List<SecretTransform> secretTransforms);
  public A withSecretTransforms(io.fabric8.servicecatalog.api.model.SecretTransform... secretTransforms);
  public Boolean hasSecretTransforms();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> addNewSecretTransform();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> addNewSecretTransformLike(SecretTransform item);
  public ServiceBindingSpecFluent.SecretTransformsNested<A> setNewSecretTransformLike(int index,SecretTransform item);
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editSecretTransform(int index);
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editFirstSecretTransform();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editLastSecretTransform();
  public ServiceBindingSpecFluent.SecretTransformsNested<A> editMatchingSecretTransform(Predicate<SecretTransformBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo();
  public UserInfo buildUserInfo();
  public A withUserInfo(UserInfo userInfo);
  public Boolean hasUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> withNewUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item);
  public ServiceBindingSpecFluent.UserInfoNested<A> editUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> editOrNewUserInfo();
  public ServiceBindingSpecFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item);
  public interface InstanceRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<ServiceBindingSpecFluent.InstanceRefNested<N>>{
    public N and();
    public N endInstanceRef();
    
  }
  public interface ParametersFromNested<N> extends Nested<N>,ParametersFromSourceFluent<ServiceBindingSpecFluent.ParametersFromNested<N>>{
    public N and();
    public N endParametersFrom();
    
  }
  public interface SecretTransformsNested<N> extends Nested<N>,SecretTransformFluent<ServiceBindingSpecFluent.SecretTransformsNested<N>>{
    public N and();
    public N endSecretTransform();
    
  }
  public interface UserInfoNested<N> extends Nested<N>,UserInfoFluent<ServiceBindingSpecFluent.UserInfoNested<N>>{
    public N and();
    public N endUserInfo();
    
  }
  
}
